@@ -1,6 +1,6 @@
 package Template::EmbeddedPerl;
 
-our $VERSION = '0.001013';
+our $VERSION = '0.001014';
 $VERSION = eval $VERSION;
 
 use warnings;
@@ -195,6 +195,14 @@ sub default_helpers {
     escape_javascript => sub { my ($self, @args) = @_; return $self->escape_javascript(@args); },
     trim              => sub { my ($self, $arg) = @_; return $self->trim($arg); },
     mtrim             => sub { my ($self, $arg) = @_; return $self->mtrim($arg); },
+    to_safe_string    => sub {
+      my ($self, @args) = @_;
+      return map {
+        Scalar::Util::blessed($_) && $_->can('to_safe_string')
+        ? $_->to_safe_string($self)
+        : $_;
+      } @args;
+    },
   );
 }
 
@@ -402,9 +410,9 @@ sub compile {
   my $flatten_or_not = '';
 
   if($self->{auto_escape} && $self->{auto_flatten_expr}) {
-    $safe_or_not = ' safe_concat ';
+    $safe_or_not = ' safe_concat to_safe_string ';
   } else {
-    $safe_or_not = $self->{auto_escape} ? ' safe ' : '';
+    $safe_or_not = $self->{auto_escape} ? ' safe to_safe_string ' : '';
     $flatten_or_not = $self->{auto_flatten_expr} ? ' join "", ' : '';
   }
 
@@ -830,6 +838,20 @@ on and want to return actual HTML you can use the C<raw> helper function. Exampl
 
 Obviously you need to be careful with this.
 
+The C<raw> helper (also available as a method on the template object) takes the string
+and turns it into an instance of L<Template::EmbeddedPerl::SafeString>.  The auto escape
+code when it sees that object knows to pass it thru without trying to escape it.  The 
+C<raw> helper has a version called C<safe> which does any needed encoding first (or passes
+unchanged any already created safe string objects).
+
+If the value is an object that does C<to_safe_string> then the object will first be converted
+to a safe string by calling it (with the template object as the first parameter).  That will
+allow you to safely stringify objects without needing to do so manually.
+
+B<NOTE> we only check for objects with the C<to_safe_string> method when using C<auto_escape>
+If you are not using this safety feature and you are manually performing any needed escaping
+then you can just use ordinary overloading to stringify your object values.
+
 =item * C<auto_flatten_expr>
 
 Boolean indicating whether to automatically flatten expressions. Default is C<< 1 >>.
